#
# spec file for package python-python-dbusmock
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-python-dbusmock
Version:        0.19
Release:        150400.1.8
Summary:        Python library for creating mock D-Bus objects
License:        LGPL-3.0-or-later
URL:            https://github.com/martinpitt/python-dbusmock
Source:         https://files.pythonhosted.org/packages/source/p/python-dbusmock/python-dbusmock-%{version}.tar.gz
BuildRequires:  %{python_module dbus-python}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(gobject-introspection-1.0)
Requires:       dbus-1-x11
Requires:       python-dbus-python
Requires:       python-gobject
Provides:       python-dbusmock = %{version}
BuildArch:      noarch
%python_subpackages

%description
With this program/Python library, one can create mock objects on D-Bus.
This is useful for writing tests for software which talks to D-Bus services
such as upower, systemd, logind, gnome-session or others, and it is hard
(or impossible without root privileges) to set the state of the real services
to what one may expect in tests.

%prep
%setup -q -n python-dbusmock-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license COPYING
%doc NEWS README.rst
%{python_sitelib}/dbusmock/
%{python_sitelib}/python_dbusmock-%{version}-py*.egg-info

%changelog
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 0.19
  - NetworkManager template: Add "StateReason" property and active connection ID
  - Add low-memory-monitor template
* Thu Mar 12 2020 tchvatal@suse.com
- Do not pull in py2 on python3 subpkg
* Tue Feb  4 2020 dimstar@opensuse.org
- Require python-dbus-python: dbusmock can't work without this
  module.
* Mon Oct 21 2019 tchvatal@suse.com
- Update to 0.18.3:
  - Fix timeouts for loaded machines and parallel tests
  - Fix tests for Python 3.8
* Wed Jan  9 2019 jengelh@inai.de
- Use noun phrase in summary. Trim description, it is not a manual.
* Mon Jan  7 2019 bjorn.lie@gmail.com
- Update URL to new home:
  * https://github.com/martinpitt/python-dbusmock
* Mon Jan  7 2019 tchvatal@suse.com
- Remove test condition
- Use %%license macro
* Mon Jan  7 2019 bjorn.lie@gmail.com
- Update to version 0.18.1:
  * test: Fix failures with systemd 239 in chroots
- Changes from version 0.18:
  * logind template: Add support for suspend-then-hibernate
  * NetworkManager template: Add GetConnectionByUuid method
  * bluez template: Add PairDevice() 'class_' parameter
  * Fix logging of unicode strings in Python 2
  * Adjust logind and timedated tests to systemd 239
- Changes from version 0.17.2:
  * NetworkManager template: Add GetDeviceByIpIface()
  * Move release tarballs from Launchpad to
    <https://github.com/martinpitt/python-dbusmock/releases>
    <https://pypi.python.org/pypi/python-dbusmock> remains as usual
- Changes from version 0.17.1:
  * Fix NetworkManager tests due to name changes from
    802-11-wireless to wifi
- Changes from version 0.17:
  * Call dbus-daemon directly instead of dbus-launch
  * Fix DBusTestCase.stop_dbus() to actually enforce a timeout
  + Fix test_timedated for changed timedatectl output format in
    systemd 235.
* Tue Nov 14 2017 toddrme2178@gmail.com
- Provide/obsolete python-dbusmock
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Rename to python-python-dbusmock to conform to python package
  naming rules
- Update to version 0.16.9
  * See changelog at https://github.com/martinpitt/python-dbusmock/blob/0.16.9/NEWS
* Sat Mar  5 2016 sor.alexei@meowr.ru
- Update to 0.16.3 (changes since 0.16.1):
  * NetworkManager template: Fix connection settings Updated signal
    emitted by wrong object.
  * NetworkManager template: Handle empty device at connection
    activation.
  * NetworkManager template: Implement secrets management in
    settings.
  * NetworkManager template test: Make the test run standalone.
* Sat Oct 31 2015 sor.alexei@meowr.ru
- Update to 0.16.1 (changes since 0.15.2):
  * NetworkManager template: Add missing properties to ethernet
    device and active connection.
  * Quiesce irrelevant PEP-8 errors with pep8 1.6.
  * NetworkManager template: Generate a new unused name in
    connection activation instead of just using the access point
    name.
  * Allow the passing of template parameters via the command-line
    as JSON strings.
  * NetworkManager template: Fix indexing bug in
    SettingsAddConnection.
* Wed Aug  5 2015 sor.alexei@meowr.ru
- Update to 0.15.2:
  * test_ofono: Do not check "private" fields.
  * timedated template: Add NTPSynchronized property and set it in
    SetNTP().
* Sun Jun  7 2015 sor.alexei@meowr.ru
- Initial package.
